beforeEach(() => {
  delete window["__VUE_DEVTOOLS_TOAST__"];
  const existingRoot = document.getElementById("root");
  if (existingRoot) {
    existingRoot.innerHTML = "";
    return;
  }
  const root = document.createElement("div");
  root.id = "root";
  document.body.appendChild(root);
});
async function getSpecsToRun(dir) {
  const testDir = dir != null ? dir : "test";
  const params = new URLSearchParams(document.location.href.split("?")[1]);
  const specParams = params.getAll("spec") || params.getAll("run") || params.getAll("specs");
  const allSpecs = specParams.reduce((acc, curr) => {
    return acc.concat(curr.split(",").map((p) => `${testDir}/${p}`));
  }, []);
  const specs = allSpecs.length ? await Promise.resolve(allSpecs) : await fetch("/test-files").then((r) => r.json());
  return specs;
}
async function setup() {
  delete window["__VUE_DEVTOOLS_TOAST__"];
  const importFile = (file) => import(`../../${file}`);
  const specsNames = async () => {
    const specs2 = await getSpecsToRun();
    return specs2.map((specName) => importFile(specName));
  };
  const [files, specs] = await Promise.all([
    fetch("/init").then((f) => f.json()),
    specsNames()
  ]);
  await Promise.all(files.map((file) => importFile(file)));
  await Promise.all(specs);
  const run = () => {
    mocha.setup({reporter: "spec"});
    mocha.checkLeaks();
    mocha.run();
  };
  return {run};
}
setup().then((s) => s.run());

export { setup };
